spacepy.empiricals.getPlasmaPause — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »

# spacepy.empiricals.getPlasmaPause

`spacepy.empiricals.` `getPlasmaPause`(ticks, model='M2002', LT='all', omnivals=None)

  Plasmapause location model(s)

  CA1992 – Carpenter, D. L., and R. R. Anderson, An ISEE/whistler model of equatorial electron density in the magnetosphere, J. Geophys. Res., 97, 1097, 1992. M2002 – Moldwin, M. B., L. Downward, H. K. Rassoul, R. Amin, and R. R. Anderson, A new model of the location of the plasmapause: CRRES results, J. Geophys. Res., 107(A11), 1339, doi:10.1029/2001JA009211, 2002.

  Parameters: | ticks : spacepy.time.Ticktock TickTock object of desired times Lpp_model : string, optional ‘CA1992’ or ‘M2002’ (default) CA1992 returns the Carpenter and Anderson model, M2002 returns the Moldwin et al. model LT : int, float requested local time sector, ‘all’ is valid option omnivals : spacepy.datamodel.SpaceData, dict dict-like containing UTC (datetimes) and Kp keys
  Returns: | out : float Plasmapause radius in Earth radii

  Examples

      >>> import spacepy.time as spt
      >>> import spacepy.empiricals as emp
      >>> ticks = spt.tickrange('2002-01-01T12:00:00','2002-01-04T00:00:00',.25)
      >>> emp.getPlasmaPause(ticks)
      array([ 6.42140002,  6.42140002,  6.42140002,  6.42140002,  6.42140002,
          6.42140002,  6.42140002,  6.26859998,  5.772     ,  5.6574    ,
          5.6574    ])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- empiricals - module with heliospheric empirical modules »